/*
 * Copyright (c) 2012-2014 Wind River Systems, Inc.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <stdio.h>
#include <zephyr/drivers/flash.h>
#include <zephyr/drivers/i2c.h>
#include <zephyr/drivers/spi.h>
#include <zephyr/drivers/gpio.h>
#include "sc7a20x/sc7a20x.h"
//#include <zephyr/logging/log_backend_uart.h>
#include <zephyr/logging/log_ctrl.h>
#include <zephyr/device.h>
#include <zephyr/drivers/uart.h>
#define SPI_NODE DT_NODELABEL(w25q128jw)
static const struct device *flash_dev = DEVICE_DT_GET(SPI_NODE);

int init_storage(void)
{
	if (!device_is_ready(flash_dev)) {
		printf("Flash device %s is not ready\n", flash_dev->name);
		return -1;
	}
	printf("Flash device %s is ready\n", flash_dev->name);

	return 0;
}

int store_offline_erase(void)
{
	int ret = flash_erase(flash_dev, 0, 0x1000);
	if (ret != 0) {
		printf("Flash erase failed! %d\n", ret);
		return -1;
	} else {
		printf("Flash erase succeeded!\n");
		return 0;
	}
}

int store_offline_data(uint8_t *buff, size_t length)
{
	int ret = flash_write(flash_dev, 0, buff, length);
	if (ret != 0) {
		printf("Flash write failed! %d\n", ret);
		return -1;
	} else {
		printf("Flash write succeeded!\n");
		return 0;
	}
}

int read_offline_data(uint8_t *read_buf, size_t length)
{
	int ret = flash_read(flash_dev, 0, read_buf, length);
	if (ret != 0) {
		printf("Flash read failed! %d\n", ret);
	} else {
		printf("Flash read succeeded! Data: %02x %02x %02x %02x %02x\n",
		read_buf[0], read_buf[1], read_buf[2], read_buf[3], read_buf[4]);
	}
	return 0;
}

int main(void)
{
	const struct device *uart_dev = DEVICE_DT_GET(DT_CHOSEN(zephyr_console));
    int err;
    if (!device_is_ready(uart_dev)) {
        printk("UART device not ready\n");
    }
	init_storage();

	printf("flash Test\n");
	store_offline_erase();
	uint8_t testBuff[16];
	for (size_t i = 0; i < 16; i++)
	{
		testBuff[i] = i+0x10;
	}
	store_offline_data(testBuff, 16);
	for (size_t i = 0; i < 16; i++)
	{
		testBuff[i] = 0;
	}	
	read_offline_data(testBuff, 16);

	printf("Hello World! %s\n", CONFIG_BOARD_TARGET);

	return 0;
}
