#include <zephyr/device.h>
#include <zephyr/drivers/i2c.h>
#include <zephyr/logging/log.h>
#include "sc7a20x.h"

LOG_MODULE_REGISTER(SC7A20H, CONFIG_SENSOR_LOG_LEVEL);


int sc7a20x_init(const struct i2c_dt_spec *i2c)
{
	//const struct sc7a20x_config *config = dev;
	uint8_t id = 0U;
    printf("SC7A20H_ADDR=0x%x\n",i2c->addr);

	if (!device_is_ready(i2c->bus)) {
		printf("I2C bus device not ready\n");
		return -ENODEV;
	}

	/* read device ID */
	if (i2c_reg_read_byte_dt(i2c,
				 SC7A20H_REG_CHIP_ID, &id) < 0) {
		printf("Could not read chip id\n");
		return -EIO;
	}

    printf("SC7A20H_CHIP_ID=0x%x\n",id);

	if (id != SC7A20H_CHIP_ID) {
		printf("Unexpected chip id (%x)\n", id);
		return -EIO;
	}	

	if (i2c_reg_write_byte_dt(i2c,
				  SC7A20H_REG_CTRL1, SC7A20H_REG_CTRL1_50HZ) < 0) {
		printf("SC7A20_REG_CTRL1 Error\n");
		return -EIO;
	}	

	if (i2c_reg_write_byte_dt(i2c,
				  SC7A20H_REG_CTRL2, SC7A20H_REG_CTRL2_RESET) < 0) {
		printf("SC7A20_REG_CTRL2 Error\n");
		return -EIO;
	}		
  
	if (i2c_reg_write_byte_dt(i2c,
				  SC7A20H_REG_CTRL3, SC7A20H_REG_CTRL3_INT1) < 0) {
		printf("SC7A20_REG_CTRL3 Error\n");
		return -EIO;
	}	

	if (i2c_reg_write_byte_dt(i2c,
				  SC7A20H_REG_CTRL4, SC7A20H_REG_CTRL4_BDU) < 0) {
		printf("SC7A20_REG_CTRL4 Error\n");
		return -EIO;
	}	   

	if (i2c_reg_write_byte_dt(i2c,
				  SC7A20H_REG_CLICK_COEFF1, SC7A20H_REG_CLICK_COEFF1_THRESHOLD) < 0) {
		printf("SC7A20_REG_CLICK_COEFF1 Error\n");
		return -EIO;
	}	  

	if (i2c_reg_write_byte_dt(i2c,
				  SC7A20H_REG_CLICK_COEFF2, SC7A20H_REG_CLICK_COEFF2_THRESHOLD) < 0) {
		printf("SC7A20_REG_CLICK_COEFF2 Error\n");
		return -EIO;
	}  

	if (i2c_reg_write_byte_dt(i2c,
				  SC7A20H_REG_CLICK_COEFF3, SC7A20H_REG_CLICK_COEFF3_THRESHOLD) < 0) {
		printf("SC7A20_REG_CLICK_COEFF3 Error\n");
		return -EIO;
	}          
}


void sc7a20x_readRaw(const struct i2c_dt_spec *i2c, sc7a20xRaw_t* r_data)
{
    uint8_t output_reg = SC7A20H_REG_OUTPUT | SC7A20H_MULTI_READ_FLG;
    if(i2c_burst_read_dt(i2c,
                output_reg, r_data, 6) < 0) {
        printf("sc7a20x read Raw err\n");
        return -EIO;   
    }
    r_data->x >>= 4;
    r_data->y >>= 4;
    r_data->z >>= 4;
    printf("x=%d,y=%d,z=%d\n",r_data->x,r_data->y,r_data->z);
}
